@@ -89,8 +89,13 @@
 #define getMIN(a,b) (a < b ? a : b)
 #define getMAX(a,b) (a > b ? a : b)
 
+#ifdef HAVE_SYS_PARAM_H
+# include <sys/param.h>
+#endif
+
+/* last resort */
 #ifndef MAXPATHLEN
-# define MAXPATHLEN 128
+# define MAXPATHLEN 1024
 #endif
 
 /* upon startup, each input file is put into an element of this array,
@@ -248,7 +253,7 @@ struct gstat {
 
 /* this can be overridden from config.h via ./configure --with-logfile .. */
 #ifndef DEFAULT_LOGFILE
-# define DEFAULT_LOGFILE "/var/httpd/apache_log"
+# define DEFAULT_LOGFILE "/var/log/access_log"
 #endif
 #define DEFAULT_CIRCLE_SIZE 30
 #define DEFAULT_CIRCLE_MODE TIMED_CIRCLE
@@ -270,7 +275,7 @@ int read_key(int ch);
 
 #define SEEK_TO_END true
 #define NO_SEEK_TO_END false
-int new_file(char *filename, bool do_seek_to_end);
+int new_file(const char *filename, bool do_seek_to_end);
 
 void usage(void);
 int dprintf(const char *fmt, ...);
